@@ -2,7 +2,7 @@
  *  cache-mysql.c
  *  mod_musicindex
  *
- *  $Id: cache-mysql.c 947 2010-06-07 11:06:01Z varenet $
+ *  $Id: cache-mysql.c 955 2011-08-06 14:40:17Z varenet $
  *
  *  Created by Thibaut VARENE on Tue Feb 22 2005.
  *  Copyright (c) 2005,2007,2009-2010 Thibaut VARENE
@@ -49,7 +49,7 @@
  * @todo clean error handler when data corruption happens.
  *
  * @author Thibaut Varene
- * @version $Revision: 947 $
+ * @version $Revision: 955 $
  * @date 2005,2007,2009-2010
  */
 
@@ -76,9 +76,6 @@
 
 /* http://dev.mysql.com/doc/mysql/en/c.html */
 
-/* for now we connect/disconnect on almost every request. we'll see later
-if we can optimize that a little (persistent connexions). */
-
 /** mysql connexion settings */
 static struct {
 	char user[SQL_SMAX_UPD];	/**< mysql db user */
@@ -185,12 +182,12 @@ mysql_cache_init(server_rec *s, const char *const setup_string)
 	const char const drop_tfiles[] = "DROP TABLE IF EXISTS `" TABLE_FILES "`";
 	const char const create_tfiles[] = "CREATE TABLE `" TABLE_FILES "` ("
 			"`id` MEDIUMINT UNSIGNED SERIAL DEFAULT VALUE,"	/* 16,777,215 files. Call me when you overflow! */
-			"`pid` SMALLINT UNSIGNED NOT NULL,"
+			"`pid` SMALLINT UNSIGNED NOT NULL REFERENCES `" TABLE_DIRS "`(`id`),"	/* XXX should eventually be a FOREIGN KEY() */
 			"`filetype` TINYINT NOT NULL,"	/* XXX this should be an enum, but I can't figure out how to do it without hardcoding values */
 			"`flags` TINYINT UNSIGNED NOT NULL,"
 			"`track` TINYINT UNSIGNED NOT NULL,"
 			"`posn` TINYINT UNSIGNED NOT NULL,"
-			"`cvers` TINYINT UNSIGNED NOT NULL," /* XXX this should be useless since we trash the whole cache on version bums... */
+			"`cvers` TINYINT UNSIGNED NOT NULL," /* XXX this should be useless since we trash the whole cache on version bumps... */
 			"`date` SMALLINT UNSIGNED NOT NULL,"
 			"`freq` SMALLINT UNSIGNED NOT NULL,"
 			"`length` SMALLINT UNSIGNED NOT NULL,"
