@@ -2,7 +2,7 @@
  *  html.c
  *  mod_musicindex
  *
- *  $Id: html.c 927 2010-05-26 13:13:59Z varenet $
+ *  $Id: html.c 962 2011-10-31 17:32:29Z varenet $
  *
  *  Created by Thibaut VARENE on Thu Mar 20 2003.
  *  Copyright (c) 2003-2006 Regis BOUDIN
@@ -20,7 +20,7 @@
  *
  * @author Regis Boudin
  * @author Thibaut Varene
- * @version $Revision: 927 $
+ * @version $Revision: 962 $
  * @date 2003-2010
  *
  * That file groups all functions related to HTML and assimilated
@@ -53,6 +53,9 @@
 #ifdef HAVE_DIRENT_H
 #include <dirent.h>	/* opendir */
 #endif
+#ifdef HAVE_SETLOCALE
+#include <locale.h>
+#endif
 
 static const char const Gfavicon[] = "sound.png";
 static const char const Gcd_icon[] = "general.png";
@@ -96,6 +99,9 @@ list_songs(request_rec *r, const mu_pack *const pack, const mu_config *const con
 	const char * restrict current = NULL, * restrict new = NULL;
 	char * restrict codeduri = NULL;
 	unsigned long tlength = 0, tsize = pack->fsize;
+#ifdef HAVE_SETLOCALE
+	struct lconv *clconv = localeconv();
+#endif
 
 	ap_rputs("  <tr class=\"title\">\n", r);
 
@@ -295,7 +301,11 @@ list_songs(request_rec *r, const mu_pack *const pack, const mu_config *const con
 					if (conf->options & MI_QUICKPL)
 						break;
 					if (q->freq)
+#ifdef HAVE_SETLOCALE
+						ap_rprintf(r, "   <td class=\"Freq\"><acronym title=\"kHz\">%d%s%d</acronym></td>\n", q->freq / 1000, clconv->decimal_point, q->freq % 1000 / 100);
+#else
 						ap_rprintf(r, "   <td class=\"Freq\"><acronym title=\"kHz\">%d.%d</acronym></td>\n", q->freq / 1000, q->freq % 1000 / 100);
+#endif
 					else
 						ap_rputs( "   <td></td>\n", r);
 					break;
@@ -315,7 +325,11 @@ list_songs(request_rec *r, const mu_pack *const pack, const mu_config *const con
 					ap_rprintf(r, "   <td class=\"Genre\">%s</td>\n", q->genre ? ap_escape_html(r->pool, q->genre) : "");
 					break;
 				case SB_SIZE:
+#ifdef HAVE_SETLOCALE
+					ap_rprintf(r, "   <td class=\"Size\"><acronym title=\"MB\">%ld%s%ld</acronym></td>\n", q->size>>20, clconv->decimal_point, (((q->size>>10)%1024)*10)>>10);	/* get kB residue *10/1024 (instead of /102.4) */ 
+#else
 					ap_rprintf(r, "   <td class=\"Size\"><acronym title=\"MB\">%ld.%ld</acronym></td>\n", q->size>>20, (((q->size>>10)%1024)*10)>>10);	/* get kB residue *10/1024 (instead of /102.4) */ 
+#endif
 					break;
 				case SB_FILENAME:
 					ap_rvputs(r, "   <td class=\"Filename\">", ap_escape_html(r->pool, q->filename), "</td>\n", NULL);
@@ -339,9 +353,15 @@ list_songs(request_rec *r, const mu_pack *const pack, const mu_config *const con
 			"var m=inpt.name.match(/-/g);if((inpt.name.substr(0,4)=='file') && (m<1)) inpt.checked=this.form.all.checked}\" />",
 			_("Select All"), " - ", NULL);
 	
-	ap_rprintf(r, "%s: %ld:%.2ld:%.2ld - %s: %ld.%ld MB</th>\n  </tr>\n",
-			   _("Total Length"), tlength / 60 / 60, tlength / 60 % 60, tlength % 60,
-			   _("Total Size"), tsize >> 20, (((tsize >> 10) % 1024) * 10) >> 10);
+	ap_rprintf(r, "%s: %ld:%.2ld:%.2ld - %s: %ld%s%ld MB</th>\n  </tr>\n",
+			_("Total Length"), tlength / 60 / 60, tlength / 60 % 60, tlength % 60,
+			_("Total Size"), tsize >> 20,
+#ifdef HAVE_SETLOCALE
+			clconv->decimal_point,
+#else
+			".",
+#endif
+			(((tsize >> 10) % 1024) * 10) >> 10);
 	
 	return fld;
 }
@@ -450,12 +470,24 @@ void send_head(request_rec *r, const mu_config *const conf)
 	request_rec *subreq = NULL;
 	const mu_config *localconf = NULL;
 
-	ap_rputs("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
+	/* this could arguably be reduced if treated directly at the setlocale()
+	call in mod_musicindex.c - XXX TO TEST */
+#ifdef HAVE_SETLOCALE
+	if ((uri = setlocale(LC_ALL, NULL))) { /* query current locale */
+		/* get the ISO 639 language code */
+		if ((u = strchr(uri, '.')))
+			*u = '\0';
+	}
+#else
+	uri = "en";
+#endif
+
+	ap_rvputs(r, "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
 		"<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.1//EN\" "
 		"\"http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd\">\n"
-		"<html xmlns=\"http://www.w3.org/1999/xhtml\" xml:lang=\"en\">\n"
+		"<html xmlns=\"http://www.w3.org/1999/xhtml\" xml:lang=\"", uri, "\" lang=\"", uri, "\">\n"
 		"<head>\n"
-		" <meta name=\"generator\" content=\"" MUSIC_HEADER_STRING "\" />\n", r);
+		" <meta name=\"generator\" content=\"" MUSIC_HEADER_STRING "\" />\n", NULL);
 
 	/* XXX REVISIT: restoring a feature with probably not too shabby code? */
 	/* dive into user's customisations, if any */
@@ -1085,6 +1117,9 @@ void send_foot(request_rec *r, const mu_config *const conf, const STRUCTTV *tvbe
 	request_rec *subreq = ap_sub_req_lookup_uri(conf->directory, r, NULL);
 #ifdef HAVE_GETTIMEOFDAY
 	struct timeval tvend, tvres;
+#ifdef HAVE_SETLOCALE
+	struct lconv *tlconv = NULL;
+#endif
 #endif
 	
 	ap_rputs("<!-- begin footer -->\n"
@@ -1130,7 +1165,12 @@ void send_foot(request_rec *r, const mu_config *const conf, const STRUCTTV *tvbe
 	gettimeofday(&tvend, NULL);
 	timersub(&tvend, tvbegin, &tvres);
 	ap_rputs(" <div id=\"timing\">", r);
+#ifdef HAVE_SETLOCALE
+	tlconv = localeconv();
+	ap_rprintf(r, _("in %u%s%.6u s"), tvres.tv_sec, tlconv->decimal_point, tvres.tv_usec);
+#else
 	ap_rprintf(r, _("in %u.%.6u s"), tvres.tv_sec, tvres.tv_usec);
+#endif
 	ap_rputs("</div>\n", r);
 #endif
 
