@@ -2,7 +2,7 @@
  *  mod_musicindex.c
  *  mod_musicindex
  *
- *  $Id: mod_musicindex.c 949 2010-09-02 11:14:32Z varenet $
+ *  $Id: mod_musicindex.c 956 2011-08-13 15:03:13Z varenet $
  *
  *  Created by Regis BOUDIN on Sat Dec 28 2002.
  *  Copyright (c) 2002-2006 Regis BOUDIN
@@ -129,7 +129,7 @@
  * This file is the core of the module. It contains Apache's mandatory stuff.
  *
  * @author Regis Boudin
- * @version $Revision: 949 $
+ * @version $Revision: 956 $
  * @date 2002-2008
  * @date 2010
  *
@@ -365,7 +365,10 @@ static int handle_musicindex(request_rec *r)
 		ap_set_content_type(r, "text/xml; charset=\"utf-8\"");
 	}
 	else {
-		ap_set_content_type(r, "text/html; charset=\"utf-8\"");
+		if (is_msie_user_agent(r))	/* IE derps on true XML */
+			ap_set_content_type(r, "text/html; charset=\"utf-8\"");
+		else
+			ap_set_content_type(r, "application/xhtml+xml; charset=\"utf-8\"");
 
 		/* If we have a cookie string, send it */
 		if (conf->custom_list != NULL)
