@@ -2,7 +2,7 @@
  *  playlist-mp4.c
  *  mod_musicindex
  *
- *  $Id: playlist-mp4.c 948 2010-06-07 12:14:29Z varenet $
+ *  $Id: playlist-mp4.c 960 2011-10-31 17:08:55Z varenet $
  *
  *  Created by Thibaut VARENE on Tue Sep  2 2004.
  *  Copyright (c) 2004-2005,2007,2010 Thibaut VARENE
@@ -18,7 +18,7 @@
  * MP4 files management system.
  *
  * @author Thibaut Varene
- * @version $Revision: 948 $
+ * @version $Revision: 960 $
  * @date 2004-2005
  * @date 2007
  * @date 2010
@@ -85,8 +85,12 @@ mu_ent *make_mp4_entry(request_rec *r, apr_pool_t *pool, FILE *const in,
 	/* XXX We could probably rely on the trackType test only though */
 	if (!mp4_ext_check(names->filename))
 		goto exit;
-
+		
+#ifdef MP4_DETAILS_ALL /* braindead API */
 	mp4file = MP4Read(names->filename, 0);
+#else
+	mp4file = MP4Read(names->filename);
+#endif
 	if (mp4file == MP4_INVALID_FILE_HANDLE)
 		goto exit;
 	
@@ -157,7 +161,11 @@ mu_ent *make_mp4_entry(request_rec *r, apr_pool_t *pool, FILE *const in,
 	}
 	
 fail:
+#ifdef MP4_CLOSE_DO_NOT_COMPUTE_BITRATE /* still braindamaged */
+	MP4Close(mp4file, 0);
+#else
 	MP4Close(mp4file);
+#endif
 
 exit:
 	return p;
