@@ -2,7 +2,7 @@
  *  playlist-mp4.h
  *  mod_musicindex
  *
- *  $Id: playlist-mp4.h 566 2006-02-04 01:14:20Z boudinr $
+ *  $Id: playlist-mp4.h 742 2007-04-23 13:15:36Z varenet $
  *
  *  Created by Thibaut VARENE on Tue Sep  2 2004.
  *  Copyright (c) 2004 Thibaut VARENE
@@ -19,6 +19,6 @@
 #include "mod_musicindex.h"
 
 mu_ent *make_mp4_entry(request_rec *r, apr_pool_t *pool, FILE *const in,
-	mu_ent *const head, const mu_config *const conf, mu_ent_names *const names);
+	const mu_config *const conf, mu_ent_names *const names);
 
 #endif /* _PLAYLIST_MP4_H */
